Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(73)

Unified Diff: net/base/dnsrr_resolver.h

Issue 6526059: Plumb through NetworkChangeNotifier::IsOffline() to WebKit, enabling (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Appease the C++ type system Created 9 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « jingle/notifier/communicator/login.cc ('k') | net/base/host_resolver_impl.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: net/base/dnsrr_resolver.h
diff --git a/net/base/dnsrr_resolver.h b/net/base/dnsrr_resolver.h
index 3280774d653d47a0e45eef435e8dca202830a30e..a9ff84b3bc7b8e573a70233dad4164c0c626b61c 100644
--- a/net/base/dnsrr_resolver.h
+++ b/net/base/dnsrr_resolver.h
@@ -67,7 +67,7 @@ class RRResolverJob;
//
// A DnsRRResolver must be used from the MessageLoop which created it.
class DnsRRResolver : public base::NonThreadSafe,
- public NetworkChangeNotifier::Observer {
+ public NetworkChangeNotifier::IPAddressObserver {
public:
typedef intptr_t Handle;
@@ -105,7 +105,7 @@ class DnsRRResolver : public base::NonThreadSafe,
// must not have already been called.
void CancelResolve(Handle handle);
// Implementation of NetworkChangeNotifier::Observer
virtual void OnIPAddressChanged();
private:
« no previous file with comments | « jingle/notifier/communicator/login.cc ('k') | net/base/host_resolver_impl.h » ('j') | no next file with comments »
@@ -105,7 +105,7 @@ class DnsRRResolver : public base::NonThreadSafe,
// must not have already been called.
void CancelResolve(Handle handle);
- // Implementation of NetworkChangeNotifier::Observer
+ // Implementation of NetworkChangeNotifier::IPAddressObserver
virtual void OnIPAddressChanged();
private:

Powered by Google App Engine
This is Rietveld 408576698